==> SCENARIbuilder_3.3.0rc2_lin.tgz: bin/scBuilder/defaults/preferences/confGeneral.js <==

			// ###
			// # Prfrences SCENARI ventuellement surcharges dans allOveride.js
			// #
			pref("toolkit.defaultChromeURI", "chrome://scenaricms/content/deskwsp/deskwsp.xul");
			//Ne demande pas confirmation pour ouvrir des application externes.
			pref("network.protocol-handler.warn-external-default", false);
			// SCENARI : Ne pas utiliser un dossier prdfini pour le tlchargement, masquer la fenetre de tlcharement
			pref("browser.download.useDownloadDir", false);
			pref("browser.download.manager.focusWhenStarting", false);
			pref("browser.download.manager.showWhenStarting", false);
			pref("browser.download.manager.useWindow", false);
			// SCENARI : Coller dans un editor.singleLine, du multiline en remplaant les CR par des ' '
			//   The 5 possible options for editor.singleLine.pasteNewlines are:
			//   0. paste newlines intact
			//   1. paste up to the first newline
			//   2. replace newlines with spaces
			//   3. strip newlines
			//   4. replace with commas
			pref("editor.singleLine.pasteNewlines",     1);
			//surcharge de la langue
			pref("general.useragent.locale", "fr-FR");
			// SCENARI : Pour dition Inline : 
			pref("editor.custom_direction", "none");
			pref("editor.custom_language", "");
			pref("editor.custom_charset", "UTF-8");
			pref("editor.use_custom_colors", false);
			
			//Dlai avant warning script JS trop long.
			pref("dom.max_chrome_script_run_time", 30);
			pref("dom.max_script_run_time", 30);
			
			//spellcheck et languages
			pref("layout.spellcheckDefault", 2);
			pref("extensions.spellcheck.inline.max-misspellings", 500);
			pref("spellchecker.dictionary", "fr-FR");
			
			//Prefs utilises au fonctionnement des fenetres des maj
			pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
			pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul?type=themes");
			pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul?type=extensions");
			pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes");
			pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
			pref("extensions.update.enabled", false);
			pref("extensions.update.interval", 86400);
			pref("extensions.dss.enabled", false);
			pref("extensions.dss.switchPending", false);
			pref("extensions.ignoreMTimeChanges", false);
			pref("extensions.logging.enabled", false);
			pref("general.skins.selectedSkin", "classic/1.0");
			pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.checkCompatibility", false);
			
			// hack de nsExtensionManager : permet de ne pas afficher la fenetre de compatibilit des extensions au premier dmarrage de l'appli
			pref("scenari.extensions.showMigrateWindow", false);
			
			// permet d'interprter le numro de version
			pref("scenari.version.minor.length", 1);//Permet de spcifier la taille de la version mineure de communication. 0 => que la vMineur de comm correspond  tout le paramtre @mineur
			
			pref("app.update.silent", true);
			pref("app.update.auto", false);
			
			// Execution externe des protocoles :
			pref("network.protocol-handler.expose.mailto", false);
			pref("network.protocol-handler.expose.mailbox", false);
			pref("network.protocol-handler.expose.http", false);
			pref("network.protocol-handler.expose.https", false);
			pref("network.protocol-handler.warn-external.http", false);
			pref("network.protocol-handler.warn-external.https", false);
			
			pref("scenari.installExtensionMode", "inProfile");//[inProfile | inApplication]
			pref("app.name","SCENARIbuilder");
			pref("app.version.developmentStage","rc2");
			pref("app.version","3.3.008");
			pref("app.extensions.version","3.3.008");
			// TJS SURCHARGEE pref("scenari.urlServerLocal", "serverlocal:8076");
			pref("scenari.reposCmsServerName", "scServer");
			pref("scenari.jvm.xms", "256M");
			pref("scenari.jvm.xmx", "256M");

==> SCENARIbuilder_3.3.1_lin.tgz: bin/scBuilder/defaults/preferences/confGeneral.js <==

			// ###
			// # Prfrences SCENARI ventuellement surcharges dans allOveride.js
			// #
			pref("toolkit.defaultChromeURI", "chrome://scenaricms/content/deskwsp/deskwsp.xul");
			//Ne demande pas confirmation pour ouvrir des application externes.
			pref("network.protocol-handler.warn-external-default", false);
			// SCENARI : Ne pas utiliser un dossier prdfini pour le tlchargement, masquer la fenetre de tlcharement
			pref("browser.download.useDownloadDir", false);
			pref("browser.download.manager.focusWhenStarting", false);
			pref("browser.download.manager.showWhenStarting", false);
			pref("browser.download.manager.useWindow", false);
			// SCENARI : Coller dans un editor.singleLine, du multiline en remplaant les CR par des ' '
			//   The 5 possible options for editor.singleLine.pasteNewlines are:
			//   0. paste newlines intact
			//   1. paste up to the first newline
			//   2. replace newlines with spaces
			//   3. strip newlines
			//   4. replace with commas
			pref("editor.singleLine.pasteNewlines",     1);
			//surcharge de la langue
			pref("general.useragent.locale", "fr-FR");
			// SCENARI : Pour dition Inline : 
			pref("editor.custom_direction", "none");
			pref("editor.custom_language", "");
			pref("editor.custom_charset", "UTF-8");
			pref("editor.use_custom_colors", false);
			
			//Dlai avant warning script JS trop long.
			pref("dom.max_chrome_script_run_time", 30);
			pref("dom.max_script_run_time", 30);
			
			//spellcheck et languages
			pref("layout.spellcheckDefault", 2);
			pref("extensions.spellcheck.inline.max-misspellings", 500);
			pref("spellchecker.dictionary", "fr-FR");
			
			//Prefs utilises au fonctionnement des fenetres des maj
			pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
			pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul?type=themes");
			pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul?type=extensions");
			pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes");
			pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
			pref("extensions.update.enabled", false);
			pref("extensions.update.interval", 86400);
			pref("extensions.dss.enabled", false);
			pref("extensions.dss.switchPending", false);
			pref("extensions.ignoreMTimeChanges", false);
			pref("extensions.logging.enabled", false);
			pref("general.skins.selectedSkin", "classic/1.0");
			pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
			pref("extensions.checkCompatibility", false);
			
			// hack de nsExtensionManager : permet de ne pas afficher la fenetre de compatibilit des extensions au premier dmarrage de l'appli
			pref("scenari.extensions.showMigrateWindow", false);
			
			// permet d'interprter le numro de version
			pref("scenari.version.minor.length", 1);//Permet de spcifier la taille de la version mineure de communication. 0 => que la vMineur de comm correspond  tout le paramtre @mineur
			
			pref("app.update.silent", true);
			pref("app.update.auto", false);
			
			// Execution externe des protocoles :
			pref("network.protocol-handler.expose.mailto", false);
			pref("network.protocol-handler.expose.mailbox", false);
			pref("network.protocol-handler.expose.http", false);
			pref("network.protocol-handler.expose.https", false);
			pref("network.protocol-handler.warn-external.http", false);
			pref("network.protocol-handler.warn-external.https", false);
			
			pref("scenari.installExtensionMode", "inProfile");//[inProfile | inApplication]
			pref("app.name","SCENARIbuilder");
			pref("app.version.developmentStage","");
			pref("app.version","3.3.100");
			pref("app.extensions.version","3.3.100");
			// TJS SURCHARGEE pref("scenari.urlServerLocal", "serverlocal:8076");
			pref("scenari.reposCmsServerName", "scServer");
			pref("scenari.jvm.xms", "256M");
			pref("scenari.jvm.xmx", "256M");
